@@ -89,7 +89,7 @@ prepare_param_in_pxe_cfg(){
     clonezilla-live|gparted-live)
        # TODO: get the boot parameter from isolinux
        # Find the IP address of this server. Here we choose the first one in the list, since it's just an example.
-       server_IP="$(LANG=C get-all-nic-ip -i | awk -F" " '{print $1}')"
+       server_IP="$(LC_ALL=C get-all-nic-ip -i | awk -F" " '{print $1}')"
        if [ -z "$cl_gp_boot_param" ]; then
          append_param_in_pxe_cfg="initrd=$nbi_initrd boot=live union=aufs noswap noprompt nolocales vga=788 fetch=tftp://$server_IP/$squashfs_file ip=frommedia"
        else
@@ -586,7 +586,7 @@ install_SL(){
       initrd_filename="$(basename $oldinitrd)"
       # The append line e.g.:
       # append initrd=/live/initrd1.img boot=live union=aufs    ocs_live_run="ocs-live-general" ocs_live_extra_param="" ocs_live_keymap="" ocs_live_batch="no" ocs_lang="" vga=791 ip=frommedia nolocales
-      cl_gp_boot_param="$(LANG=C grep -Eiw "append" $isomnt/isolinux/isolinux.cfg  | grep -Eiw $initrd_filename | head -n 1 | sed -r -e "s/append//g" -e "s/initrd=.*$initrd_filename[[:space:]]+//g" | sed -e "s/^[[:space:]]*//g")"
+      cl_gp_boot_param="$(LC_ALL=C grep -Eiw "append" $isomnt/isolinux/isolinux.cfg  | grep -Eiw $initrd_filename | head -n 1 | sed -r -e "s/append//g" -e "s/initrd=.*$initrd_filename[[:space:]]+//g" | sed -e "s/^[[:space:]]*//g")"
       ;;
   esac
   
